@@ -50,9 +50,9 @@ namespace zypp
     }
 
     //using boost::interprocess pointer because it allows a custom deleter
-    typedef boost::interprocess::scoped_ptr<gpgme_data, boost::function<void (gpgme_data_t)>> GpgmeDataPtr;
-    typedef boost::interprocess::scoped_ptr<_gpgme_key, boost::function<void (gpgme_key_t)>>  GpgmeKeyPtr;
-    typedef boost::interprocess::scoped_ptr<FILE, boost::function<int (FILE *)>> FILEPtr;
+    using GpgmeDataPtr = boost::interprocess::scoped_ptr<gpgme_data, boost::function<void (gpgme_data_t)>>;
+    using GpgmeKeyPtr = boost::interprocess::scoped_ptr<_gpgme_key, boost::function<void (gpgme_key_t)>>;
+    using FILEPtr = boost::interprocess::scoped_ptr<FILE, boost::function<int (FILE *)>>;
 
     struct GpgmeErr
     {
@@ -107,9 +107,15 @@ namespace zypp
     Impl()
     { boost::call_once( gpgme_init_once, initGpgme ); }
 
-    ~Impl()
-    { if ( _ctx ) gpgme_release( _ctx ); }
+    Impl(const Impl &) = delete;
+    Impl(Impl &&) = delete;
+    Impl &operator=(const Impl &) = delete;
+    Impl &operator=(Impl &&) = delete;
 
+    ~Impl() {
+      if (_ctx)
+        gpgme_release(_ctx);
+    }
 
     /** Return all fingerprints found in \a signature_r. */
     std::list<std::string> readSignaturesFprs( const Pathname & signature_r )
@@ -346,7 +352,6 @@ std::list<PublicKeyData> KeyManagerCtx::listKeys()
   return ret;
 }
 
-#if 1
 std::list<PublicKeyData> KeyManagerCtx::readKeyFromFile( const Pathname & keyfile_r )
 {
   // bsc#1140670: GPGME does not support reading keys from a keyfile using
@@ -369,43 +374,6 @@ std::list<PublicKeyData> KeyManagerCtx::readKeyFromFile( const Pathname & keyfil
 
   return ret;
 }
-#else
-std::list<PublicKeyData> KeyManagerCtx::readKeyFromFile( const Pathname & file_r )
-{
-  std::list<PublicKeyData> ret;
-  GpgmeErr err = GPG_ERR_NO_ERROR;
-
-  AutoDispose<gpgme_data_t> data { nullptr, &gpgme_data_release };
-  if ( (err = gpgme_data_new_from_file( &(*data), file_r.c_str(), 1 )) != GPG_ERR_NO_ERROR ) {
-    ERR << "gpgme_data_new_from_file " << file_r << ": " << err << endl;
-    return ret;
-  }
-
-  // Reset gpgme_keylist_mode on return!
-  AutoDispose<gpgme_keylist_mode_t> guard { gpgme_get_keylist_mode( _pimpl->_ctx ), bind( &gpgme_set_keylist_mode, _pimpl->_ctx, _1 ) };
-  // Let listed keys include signatures (required if PublicKeyData are created from the key)
-  if ( (err = gpgme_set_keylist_mode( _pimpl->_ctx, GPGME_KEYLIST_MODE_LOCAL | GPGME_KEYLIST_MODE_SIGS )) != GPG_ERR_NO_ERROR ) {
-    ERR << "gpgme_set_keylist_mode: " << err << endl;
-    return ret;
-  }
-
-  if ( (err = gpgme_op_keylist_from_data_start( _pimpl->_ctx, data, 0 )) != GPG_ERR_NO_ERROR ) {
-    ERR << "gpgme_op_keylist_from_data_start " << file_r << ": " << err << endl;
-    return ret;
-  }
-  // Close list operation on return!
-  AutoDispose<gpgme_ctx_t> guard2 { _pimpl->_ctx, &gpgme_op_keylist_end };
-
-  AutoDispose<gpgme_key_t> key { nullptr, &gpgme_key_release };
-  for ( ; gpgme_op_keylist_next( _pimpl->_ctx, &(*key) ) == GPG_ERR_NO_ERROR; key.getDispose()( key ) ) {
-    PublicKeyData data { PublicKeyData::fromGpgmeKey( key ) };
-    if ( data )
-      ret.push_back( data );
-  }
-
-  return ret;
-}
-#endif
 
 bool KeyManagerCtx::verify(const Pathname &file, const Pathname &signature)
 {
@@ -419,7 +387,7 @@ bool KeyManagerCtx::exportKey(const std::string &id, std::ostream &stream)
   GpgmeKeyPtr foundKey;
 
   //search for requested key id
-  gpgme_key_t key;
+  gpgme_key_t key = nullptr;
   gpgme_op_keylist_start(_pimpl->_ctx, NULL, 0);
   while (!(err = gpgme_op_keylist_next(_pimpl->_ctx, &key))) {
     if (key->subkeys && id == str::asString(key->subkeys->keyid)) {
@@ -541,7 +509,7 @@ bool KeyManagerCtx::Impl::importKey(GpgmeDataPtr &data, Callback &&calcDataSize)
 
 bool KeyManagerCtx::deleteKey(const std::string &id)
 {
-  gpgme_key_t key;
+  gpgme_key_t key = nullptr;
   GpgmeErr err = GPG_ERR_NO_ERROR;
 
   gpgme_op_keylist_start(_pimpl->_ctx, NULL, 0);
